]> sigrok.org Git - pulseview.git/blobdiff - main.cpp
Generate a config.h file for versioning
[pulseview.git] / main.cpp
index bb95f9ba4ef8e0e0ad9467ba6e8b0829b847e901..661c84a6d23c0ea40d128a52fe8584608f624fd7 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -1,5 +1,5 @@
 /*
* This file is part of the sigrok project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>
  *
@@ -26,15 +26,18 @@ extern "C" {
 
 #include <QtGui/QApplication>
 #include <QDebug>
-#include "mainwindow.h"
+
+#include "pv/mainwindow.h"
+
+#include "config.h"
 
 int main(int argc, char *argv[])
 {
        QApplication a(argc, argv);
 
        /* Set some application metadata. */
-       QApplication::setApplicationVersion(APP_VERSION);
-       QApplication::setApplicationName("sigrok-qt");
+       QApplication::setApplicationVersion(PV_VERSION_STRING);
+       QApplication::setApplicationName("PulseView");
        QApplication::setOrganizationDomain("http://www.sigrok.org");
 
        /* Initialise libsigrok */
@@ -52,8 +55,18 @@ int main(int argc, char *argv[])
        /* Load the protocol decoders */
        srd_decoder_load_all();
 
+       /* Initialize all libsigrok drivers. */
+       sr_dev_driver **const drivers = sr_driver_list();
+       for (sr_dev_driver **driver = drivers; *driver; driver++) {
+               if (sr_driver_init(*driver) != SR_OK) {
+                       qDebug("Failed to initialize driver %s",
+                               (*driver)->name);
+                       return 1;
+               }
+       }
+
        /* Initialise the main window */
-       MainWindow w;
+       pv::MainWindow w;
        w.show();
 
        /* Run the application */
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the PulseView project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>